@@ -14,7 +14,7 @@ class Radiko():
 
    authToken = None
    region = None
-   version = "1.1.0"
+   version = "1.1.2"
 
    def __init__(self, regionId=None):
 
@@ -254,20 +254,17 @@ class Radiko():
          f.write(audio)
 
    def getLiveStationStreamUrls(self, station):
-      streambase_response = requests.get(STREAM_BASE + station + ".xml")
-      streambase_list = ET.fromstring(streambase_response.text)
-      streamUrl = streambase_list[0][0].text
       a_exp = hashlib.md5(str(math.floor(random.random() * 1000000000) + math.floor(time.time())).encode()).hexdigest()
       stream_headers = {
          "X-Radiko-AuthToken": self.authToken
       }
-      stream_response = requests.get(streamUrl + "?station_id=" + station + "&l=15&lsid=" + a_exp + "&type=b", headers=stream_headers)
+      stream_response = requests.get(STREAM_BASE + "?station_id=" + station + "&l=15&lsid=" + a_exp + "&type=b", headers=stream_headers)
       stream_response.encoding = "UTF-8"
       if stream_response.status_code != requests.codes.ok:
          raise RadikoException("Failed to get playlist")
       m3u8_url = None
       for text in stream_response.text.split("\n"):
-         if text.startswith("https://"):
+         if text.startswith("https://") or text.startswith("http://"):
             m3u8_url = text
             break
       if m3u8_url is None:
@@ -277,7 +274,7 @@ class Radiko():
          raise RadikoException("Failed to get m3u8")
       streamUrls = []
       for text in m3u8_response.text.split("\n"):
-         if text.startswith("https://"):
+         if text.startswith("https://") or text.startswith("http://"):
             streamUrls.append(text)
       return streamUrls
 
